@@ -1,4 +1,5 @@
 import inspect
+import sys
 
 
 class MutuallyExclusiveArgsError(ValueError):
@@ -28,3 +29,6 @@ def mutually_exclusive(*mutually_exc_args_names: str):
         return inner
 
     return wrapper
+
+
+sys.modules[__name__] = mutually_exclusive  # type: ignore
